@@ -9,7 +9,7 @@ from pathlib import Path
 from typing import Any, List
 
 import numpy as np
-from rich.progress import track
+from rich.progress import BarColumn, Progress, SpinnerColumn, TimeRemainingColumn, track
 from rich.table import Table
 
 from . import __version__, csv_edem_batch, csv_edem_controller, csv_input, utils
@@ -35,8 +35,8 @@ def gen_input_txt(gen_dir: Path, input_file: str, info: bool = False) -> None:
             outf.write(os.linesep)
 
     console.print(f"Found [bold blue]{len(csv_files_in_curr_dir)}[/] files:")
-    for csv in csv_files_in_curr_dir:
-        if not info:
+    if not info:
+        for csv in csv_files_in_curr_dir:
             f = Path(os.curdir).resolve() / csv
             console.print(f'  {i:02d} - "{f}"')
             i += 1
@@ -54,7 +54,35 @@ def batch_input_txt(
         return
 
     batch_ctrller = csv_edem_batch.CSV_Edem_Batch(input_file, args)
-    batch_ctrller.executeBatch(progress_bar=console if not info else None)
+
+    if not info:
+        progress = Progress(
+            SpinnerColumn(),
+            "[progress.description]{task.description}",
+            BarColumn(),
+            "[progress.percentage]{task.percentage:>3.0f}%",
+            TimeRemainingColumn(),
+            "{task.fields[extra]}",
+            console=console,
+            transient=True,
+        )
+        task = progress.add_task(
+            total=batch_ctrller.getNumberOfFiles(),
+            description="Processing...",
+            extra="",
+        )
+        progress.start()
+
+        def callback_fun(file: str, file_id: int, finished: bool) -> None:
+            if finished:
+                progress.update(task, advance=1, extra="")
+            else:
+                progress.update(task, extra=f"[dim]{file_id:2d} - {Path(file).name}")
+
+    batch_ctrller.executeBatch(callback=callback_fun if not info else None)
+    time.sleep(0.1)
+    if not info:
+        progress.stop()
     excel_file: str = "batch_EDEM_files"
     batch_ctrller.saveToExcel(excel_file)
 
